==> piwigo-11.5.0.zip: piwigo/language/de_DE/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Installation';
$lang['Basic configuration'] = 'Grundkonfiguration';
$lang['Default gallery language'] = 'Standardsprache der Galerie';
$lang['Database configuration'] = 'Konfiguration der Datenbank';
$lang['Admin configuration'] = 'Administrationseinstellungen';
$lang['Start Install'] = 'Start der Installation';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Wird für die Webseitenverwaltung benötigt und wird Besuchern angezeigt.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Eine Verbindung zum Server konnte hergestellt werden, nicht aber zur Datenbank.';
$lang['Can\'t connect to server'] = 'Es konnte keine Verbindung zum Datenbankserver hergestellt werden';
$lang['Host'] = 'MySQL-Host';
$lang['User'] = 'Benutzer';
$lang['user login given by your host provider'] = 'Benutzername Ihrer MySQL-Datenbank (wie von Ihrem Hosting-Provider angegeben)';
$lang['user password given by your host provider'] = 'Kennwort Ihrer MySQL-Datenbank (wie von Ihrem Hosting-Provider angegeben)';
$lang['Database name'] = 'Name der Datenbank';
$lang['also given by your host provider'] = '(auch von Ihrem Hosting-Provider bereitgestellt)';
$lang['Database table prefix'] = 'Präfix der Datenbanktabellen';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'Präfix der Datenbanktabellen-Namen, damit Tabellen einfacher verwaltet werden können';
$lang['enter a login for webmaster'] = 'Geben Sie den Benutzernamen des Webmasters an';
$lang['webmaster login can\'t contain characters \' or "'] = 'Der Benutzername des Webmasters darf nicht die Zeichen \' und " enthalten';
$lang['please enter your password again'] = 'Bitte geben Sie Ihr Kennwort erneut ein';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Vertraulich behandeln, damit kann auf die Verwaltung zugegriffen werden';
$lang['Password [confirm]'] = 'Passwort [Bestätigung]';
$lang['verification'] = 'Wiederholen Sie das eingegebene Kennwort';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Brauchen Sie Hilfe? Stellen Sie Ihre Fragen im <a href="%s"> Piwigo-Forum</ a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Kontakt-E-Mail-Adresse (nur für angemeldete Benutzer sichtbar)';
$lang['PHP 5 is required'] = 'PHP 5.2 ist erforderlich';
$lang['It appears your webhost is currently running PHP %s.'] = 'Anscheinend läuft auf Ihrem Server die PHP-Version %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo wird versuchen, Ihre Konfiguration auf PHP 5.2 umzustellen. Zu diesem Zweck wird eine .htaccess-Datei erstellt oder geändert.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Hinweis: Sie können Ihre Konfiguration selbst ändern. Starten Sie Piwigo danach neu.';
$lang['Try to configure PHP 5'] = 'Es wird versucht, PHP 5.2 zu konfigurieren';
$lang['Sorry!'] = 'Verzeihung!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo ist nicht in der Lage, PHP 5.2 zu konfigurieren.';
$lang["You may referer to your hosting provider's support and see how you could switch to PHP 5 by yourself."] = "Sie können Kontakt zu ihrem Hosting-Provider aufnehmen und um Unterstützung bitten zur Umstellung auf PHP 5.";
$lang['Hope to see you back soon.'] = 'Hoffentlich bis bald!';
$lang['Congratulations, Piwigo installation is completed'] = 'Glückwunsch! Sie haben Piwigo erfolgreich installiert';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Sie können auch den Text aus der Box unten kopieren und in die Datei local/config/database.inc.php einfügen. (Warnung: database.inc.php darf nur reinen Text ohne Zeilenumbrüche und Leerzeichen enthalten)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Das Erstellen der Datei local/config/database.inc.php ist fehlgeschlagen.';
$lang['Download the config file'] = 'Die Konfigurationsdatei herunterladen';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Sie können die Konfigurationsdatei herunterladen und in das Verzeichnis local/config Ihrer Installation hochladen.';
$lang['Just another Piwigo gallery'] = 'Meine Piwigo-Fotogalerie';
$lang['Welcome to my photo gallery'] = 'Willkommen!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Besuchen Sie für Hilfe unser Forum: %s';
$lang['Welcome to your new installation of Piwigo!'] = 'Ihre neue Piwigo-Installation heißt Sie willkommen!';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Sie sollten Kontakt mit Ihrem Provider aufnehmen und um Unterstützung bei der Umstellung auf PHP 5.2 bitten.';
$lang['localhost or other, supplied by your host provider'] = '\'localhost\' oder Name des DB-Servers, bereitgestellt durch Ihren Hosting-Provider';
$lang['Password ']['confirm'] = 'Kennwort [Bestätigung]';

==> piwigo-15.5.0.zip: piwigo/language/de_DE/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Installation';
$lang['Basic configuration'] = 'Grundkonfiguration';
$lang['Default gallery language'] = 'Standardsprache der Galerie';
$lang['Database configuration'] = 'Konfiguration der Datenbank';
$lang['Admin configuration'] = 'Administrationseinstellungen';
$lang['Start Install'] = 'Start der Installation';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Wird für die Webseitenverwaltung benötigt und wird Besuchern angezeigt.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Eine Verbindung zum Server konnte hergestellt werden, nicht aber zur Datenbank.';
$lang['Can\'t connect to server'] = 'Es konnte keine Verbindung zum Datenbankserver hergestellt werden';
$lang['Host'] = 'MySQL-Host';
$lang['User'] = 'Benutzer';
$lang['user login given by your host provider'] = 'Benutzername Ihrer MySQL-Datenbank (wie von Ihrem Hosting-Provider angegeben)';
$lang['user password given by your host provider'] = 'Kennwort Ihrer MySQL-Datenbank (wie von Ihrem Hosting-Provider angegeben)';
$lang['Database name'] = 'Name der Datenbank';
$lang['also given by your host provider'] = '(auch von Ihrem Hosting-Provider bereitgestellt)';
$lang['Database table prefix'] = 'Präfix der Datenbanktabellen';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'Präfix der Datenbanktabellen-Namen, damit Tabellen einfacher verwaltet werden können';
$lang['enter a login for webmaster'] = 'Geben Sie den Benutzernamen des Webmasters an';
$lang['webmaster login can\'t contain characters \' or "'] = 'Der Benutzername des Webmasters darf nicht die Zeichen \' und " enthalten';
$lang['please enter your password again'] = 'Bitte geben Sie Ihr Kennwort erneut ein';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Vertraulich behandeln, damit kann auf die Verwaltung zugegriffen werden';
$lang['Password [confirm]'] = 'Passwort [Bestätigung]';
$lang['verification'] = 'Wiederholen Sie das eingegebene Kennwort';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Brauchen Sie Hilfe? Stellen Sie Ihre Fragen im <a href="%s"> Piwigo-Forum</ a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Kontakt-E-Mail-Adresse (nur für angemeldete Benutzer sichtbar)';
$lang['PHP 5 is required'] = 'PHP 5.2 ist erforderlich';
$lang['It appears your webhost is currently running PHP %s.'] = 'Anscheinend läuft auf Ihrem Server die PHP-Version %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo wird versuchen, Ihre Konfiguration auf PHP 5.2 umzustellen. Zu diesem Zweck wird eine .htaccess-Datei erstellt oder geändert.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Hinweis: Sie können Ihre Konfiguration selbst ändern. Starten Sie Piwigo danach neu.';
$lang['Try to configure PHP 5'] = 'Es wird versucht, PHP 5.2 zu konfigurieren';
$lang['Sorry!'] = 'Verzeihung!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo ist nicht in der Lage, PHP 5.2 zu konfigurieren.';
$lang["You may referer to your hosting provider's support and see how you could switch to PHP 5 by yourself."] = "Sie können Kontakt zu ihrem Hosting-Provider aufnehmen und um Unterstützung bitten zur Umstellung auf PHP 5.";
$lang['Hope to see you back soon.'] = 'Hoffentlich bis bald!';
$lang['Congratulations, Piwigo installation is completed'] = 'Glückwunsch! Sie haben Piwigo erfolgreich installiert';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Sie können auch den Text aus der Box unten kopieren und in die Datei local/config/database.inc.php einfügen. (Warnung: database.inc.php darf nur reinen Text ohne Zeilenumbrüche und Leerzeichen enthalten)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Das Erstellen der Datei local/config/database.inc.php ist fehlgeschlagen.';
$lang['Download the config file'] = 'Die Konfigurationsdatei herunterladen';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Sie können die Konfigurationsdatei herunterladen und in das Verzeichnis local/config Ihrer Installation hochladen.';
$lang['Just another Piwigo gallery'] = 'Meine Piwigo-Fotogalerie';
$lang['Welcome to my photo gallery'] = 'Willkommen!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Besuchen Sie für Hilfe unser Forum: %s';
$lang['Welcome to your new installation of Piwigo!'] = 'Ihre neue Piwigo-Installation heißt Sie willkommen!';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Sie sollten Kontakt mit Ihrem Provider aufnehmen und um Unterstützung bei der Umstellung auf PHP 5.2 bitten.';
$lang['localhost or other, supplied by your host provider'] = '\'localhost\' oder Name des DB-Servers, bereitgestellt durch Ihren Hosting-Provider';
$lang['Password ']['confirm'] = 'Kennwort [Bestätigung]';
$lang['PHP version %s required (you are running on PHP %s)'] = 'PHP-Version %s benötigt (Aktuelle PHP-Version: %s)';
